=======
Meerkat
=======

.. start-badges

|travis|
|landscape|
|version|
|wheel|
|codecov|
|gitter|

.. |supported-versions|
.. |supported-implementations|

.. |travis| image:: https://travis-ci.org/Pawamoy/django-meerkat.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/Pawamoy/django-meerkat/

.. |codecov| image:: https://codecov.io/github/Pawamoy/django-meerkat/coverage.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/Pawamoy/django-meerkat/

.. |landscape| image:: https://landscape.io/github/Pawamoy/django-meerkat/master/landscape.svg?style=flat
    :target: https://landscape.io/github/Pawamoy/django-meerkat/
    :alt: Code Quality Status

.. |version| image:: https://img.shields.io/pypi/v/django-meerkat.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/django-meerkat/

.. |downloads| image:: https://img.shields.io/pypi/dm/django-meerkat.svg?style=flat
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/django-meerkat/

.. |wheel| image:: https://img.shields.io/pypi/wheel/django-meerkat.svg?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/django-meerkat/

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/django-meerkat.svg?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/django-meerkat/

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/django-meerkat.svg?style=flat
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/django-meerkat/

.. |gitter| image:: https://badges.gitter.im/Pawamoy/django-meerkat.svg
    :alt: Join the chat at https://gitter.im/Pawamoy/django-meerkat
    :target: https://gitter.im/Pawamoy/django-meerkat?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge


.. end-badges

Security audit tool for Django sites.

License
=======

Software licensed under `MPL 2.0`_ license.

.. _MPL 2.0 : https://www.mozilla.org/en-US/MPL/2.0/

Installation
============

No release on PyPi yet. Clone the repo.

Documentation
=============

https://github.com/Pawamoy/django-meerkat/wiki

Development
===========

To run all the tests: ``tox``
